@@ -2,7 +2,7 @@
  * controller_widget.cpp : Controller Widget for the controllers
  ****************************************************************************
  * Copyright (C) 2006-2008 the VideoLAN team
- * $Id: aad30a288a824515856a90ed864595c0716e9b63 $
+ * $Id: 66fecd96ae908040de7cbe2ad73ac322a163dc8a $
  *
  * Authors: Jean-Baptiste Kempf <jb@videolan.org>
  *
@@ -71,7 +71,7 @@ SoundWidget::SoundWidget( QWidget *_parent, intf_thread_t * _p_intf,
         /* Special view, click on button shows the slider */
         b_shiny = false;
 
-        volumeControlWidget = new QFrame;
+        volumeControlWidget = new QFrame( this );
         subLayout = new QVBoxLayout( volumeControlWidget );
         subLayout->setContentsMargins( 4, 4, 4, 4 );
         volumeMenu = new QMenu( this );
@@ -122,12 +122,6 @@ SoundWidget::SoundWidget( QWidget *_parent, intf_thread_t * _p_intf,
     CONNECT( THEMIM, soundMuteChanged( bool ), this, updateMuteStatus( bool ) );
 }
 
-SoundWidget::~SoundWidget()
-{
-    delete volumeSlider;
-    delete volumeControlWidget;
-}
-
 void SoundWidget::refreshLabels()
 {
     int i_sliderVolume = volumeSlider->value();
