@@ -1,24 +1,24 @@
 /*****************************************************************************
  * mirror.c : Mirror video plugin for vlc
  *****************************************************************************
- * Copyright (C) 2009 the VideoLAN team
- * $Id: 543ee31f3a0f7c3e97028aa940346e7de978ecfd $
+ * Copyright (C) 2009 VLC authors and VideoLAN
+ * $Id: 3c0344ccba25da37c98ef1283bfc66722f9b23f8 $
  *
  * Authors: Branko Kokanovic <branko.kokanovic@gmail.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2.1 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
  *****************************************************************************/
 
 /*****************************************************************************
@@ -29,10 +29,11 @@
 # include "config.h"
 #endif
 
+#include <assert.h>
+
 #include <vlc_common.h>
 #include <vlc_plugin.h>
-
-#include <assert.h>
+#include <vlc_atomic.h>
 #include <vlc_filter.h>
 #include "filter_picture.h"
 
@@ -102,9 +103,8 @@ static int FilterCallback( vlc_object_t *, char const *,
  *****************************************************************************/
 struct filter_sys_t
 {
-    int i_split;
-    int i_direction;
-    vlc_mutex_t lock;
+    atomic_int i_split;
+    atomic_int i_direction;
 };
 
 /*****************************************************************************
@@ -146,14 +146,14 @@ static int Create( vlc_object_t *p_this )
 
     config_ChainParse( p_filter, CFG_PREFIX, ppsz_filter_options,
                        p_filter->p_cfg );
-    p_sys->i_split = var_CreateGetIntegerCommand( p_filter, CFG_PREFIX "split" );
-    p_sys->i_direction = var_CreateGetIntegerCommand( p_filter,
-                                                    CFG_PREFIX "direction" );
+    atomic_init( &p_sys->i_split,
+                 var_CreateGetIntegerCommand( p_filter, CFG_PREFIX "split" ) );
+    atomic_init( &p_sys->i_direction,
+                 var_CreateGetIntegerCommand( p_filter,
+                                                    CFG_PREFIX "direction" ) );
 
-    vlc_mutex_init( &p_sys->lock );
-
-    var_AddCallback( p_filter, CFG_PREFIX "split", FilterCallback, NULL );
-    var_AddCallback( p_filter, CFG_PREFIX "direction", FilterCallback, NULL );
+    var_AddCallback( p_filter, CFG_PREFIX "split", FilterCallback, p_sys );
+    var_AddCallback( p_filter, CFG_PREFIX "direction", FilterCallback, p_sys );
 
     p_filter->pf_video_filter = Filter;
 
@@ -168,12 +168,11 @@ static int Create( vlc_object_t *p_this )
 static void Destroy( vlc_object_t *p_this )
 {
     filter_t *p_filter = (filter_t *)p_this;
+    filter_sys_t *p_sys = p_filter->p_sys;
 
-    var_DelCallback( p_filter, CFG_PREFIX "split", FilterCallback, NULL );
-    var_DelCallback( p_filter, CFG_PREFIX "direction", FilterCallback, NULL );
-
-    vlc_mutex_destroy( &p_filter->p_sys->lock );
-    free( p_filter->p_sys );
+    var_DelCallback( p_filter, CFG_PREFIX "split", FilterCallback, p_sys );
+    var_DelCallback( p_filter, CFG_PREFIX "direction", FilterCallback, p_sys );
+    free( p_sys );
 }
 
 /*****************************************************************************
@@ -192,10 +191,8 @@ static picture_t *Filter( filter_t *p_filter, picture_t *p_pic )
     if( !p_pic ) return NULL;
 
     filter_sys_t *p_sys = p_filter->p_sys;
-    vlc_mutex_lock( &p_sys->lock );
-    b_vertical_split = p_sys->i_split == 0 ? true : false;
-    b_left_to_right = p_sys->i_direction == 0 ? true : false;
-    vlc_mutex_unlock( &p_sys->lock );
+    b_vertical_split = !atomic_load( &p_sys->i_split );
+    b_left_to_right = !atomic_load( &p_sys->i_direction );
 
     p_outpic = filter_NewPicture( p_filter );
     if( !p_outpic )
@@ -301,7 +298,7 @@ static void PlanarVerticalMirror( picture_t *p_pic, picture_t *p_outpic,
  * YUV422VerticalMirror: Mirrors vertically image byte by byte for YUV422 format
  *****************************************************************************
  * This function mirrors image vertically. It iterates for all lines in
- * image and for every line, it iterates for 4-byte chucks, properly mirroring
+ * image and for every line, iterates for 4-byte chucks, properly mirroring
  * them vertically (swapping Y components and keeping Cb and Cr components).
  * This function works only for YUV422 packed formats.
  *****************************************************************************/
@@ -592,22 +589,13 @@ static void HorizontalMirror( picture_t *p_pic, picture_t *p_outpic, int i_plane
 static int FilterCallback ( vlc_object_t *p_this, char const *psz_var,
                             vlc_value_t oldval, vlc_value_t newval, void *p_data )
 {
-    (void)oldval;    (void)p_data;
-    filter_t *p_filter = (filter_t*)p_this;
-    filter_sys_t *p_sys = p_filter->p_sys;
+    (void) p_this; (void)oldval;
+    filter_sys_t *p_sys = p_data;
 
     if( !strcmp( psz_var, CFG_PREFIX "split" ) )
-    {
-        vlc_mutex_lock( &p_sys->lock );
-        p_sys->i_split = newval.i_int;
-        vlc_mutex_unlock( &p_sys->lock );
-    }
+        atomic_store( &p_sys->i_split, newval.i_int );
     else /* CFG_PREFIX "direction" */
-    {
-        vlc_mutex_lock( &p_sys->lock );
-        p_sys->i_direction = newval.i_int;
-        vlc_mutex_unlock( &p_sys->lock );
-    }
+        atomic_store( &p_sys->i_direction, newval.i_int );
 
     return VLC_SUCCESS;
 }
